.. -*- rst -*-

=======
picraft
=======

This package provides an alternate Python API for `Minecraft Pi edition`_ on
the `Raspberry Pi`_, or `Raspberry Juice`_ on the PC for Python 2.7 (or above),
or Python 3.2 (or above).

Links
=====

* The code is licensed under the `BSD license`_
* The `source code`_ can be obtained from GitHub, which also hosts the `bug
  tracker`_
* The `documentation`_ (which includes installation, quick-start examples, and
  lots of code recipes) can be read on ReadTheDocs
* Packages can be downloaded from `PyPI`_, but reading the installation
  instructions is more likely to be useful


.. _Minecraft Pi edition: https://www.raspberrypi.org/documentation/usage/minecraft/README.md
.. _Raspberry Pi: http://www.raspberrypi.org/
.. _Raspberry Juice: http://www.stuffaboutcode.com/2014/10/minecraft-raspberryjuice-and-canarymod.html
.. _PyPI: http://pypi.python.org/pypi/picraft/
.. _documentation: http://picraft.readthedocs.org/
.. _source code: https://github.com/waveform80/picraft
.. _bug tracker: https://github.com/waveform80/picraft/issues
.. _BSD license: http://opensource.org/licenses/BSD-3-Clause

